/* automatically generated from confirmation-dialog.glade */
#ifdef __SUNPRO_C
#pragma align 4 (confirmation_dialog_ui)
#endif
#ifdef __GNUC__
static const char confirmation_dialog_ui[] __attribute__ ((__aligned__ (4))) =
#else
static const char confirmation_dialog_ui[] =
#endif
{
  "<?xml version=\"1.0\" encoding=\"UTF-8\"?><interface><requires lib=\"gt"
  "k+\" version=\"3.20\"/><object class=\"GtkMessageDialog\" id=\"dialog1\""
  "><property name=\"can_focus\">False</property><property name=\"resizabl"
  "e\">False</property><property name=\"modal\">True</property><property n"
  "ame=\"icon_name\">dialog-question</property><property name=\"type_hint\""
  ">dialog</property><property name=\"urgency_hint\">True</property><prope"
  "rty name=\"message_type\">question</property><property name=\"text\" tr"
  "anslatable=\"yes\">&lt;b&gt;&lt;big&gt;Would you like to keep this conf"
  "iguration?&lt;/big&gt;&lt;/b&gt;</property><property name=\"use_markup\""
  ">True</property><property name=\"secondary_text\" translatable=\"yes\">"
  "The previous configuration will be restored in &lt;b&gt;10 seconds&lt;/"
  "b&gt; if you do not reply to this question.</property><property name=\""
  "secondary_use_markup\">True</property><child internal-child=\"vbox\"><o"
  "bject class=\"GtkBox\"><property name=\"can_focus\">False</property><pr"
  "operty name=\"orientation\">vertical</property><property name=\"spacing"
  "\">2</property><child internal-child=\"action_area\"><object class=\"Gt"
  "kButtonBox\"><property name=\"can_focus\">False</property><property nam"
  "e=\"homogeneous\">True</property><property name=\"layout_style\">expand"
  "</property><child><object class=\"GtkButton\" id=\"button2\"><property "
  "name=\"label\" translatable=\"yes\">Keep this configuration</property><"
  "property name=\"visible\">True</property><property name=\"can_focus\">T"
  "rue</property><property name=\"can_default\">True</property><property n"
  "ame=\"has_default\">True</property><property name=\"receives_default\">"
  "True</property></object><packing><property name=\"expand\">True</proper"
  "ty><property name=\"fill\">True</property><property name=\"position\">0"
  "</property></packing></child><child><object class=\"GtkButton\" id=\"bu"
  "tton1\"><property name=\"label\" translatable=\"yes\">Restore the previ"
  "ous configuration</property><property name=\"visible\">True</property><"
  "property name=\"can_focus\">True</property><property name=\"receives_de"
  "fault\">True</property></object><packing><property name=\"expand\">True"
  "</property><property name=\"fill\">True</property><property name=\"posi"
  "tion\">1</property></packing></child></object><packing><property name=\""
  "expand\">True</property><property name=\"fill\">True</property><propert"
  "y name=\"position\">0</property></packing></child></object></child><act"
  "ion-widgets><action-widget response=\"2\">button2</action-widget><actio"
  "n-widget response=\"1\">button1</action-widget></action-widgets></objec"
  "t></interface>"
};

static const unsigned confirmation_dialog_ui_length = 2462u;

