/* automatically generated from display-dialog.glade */
#ifdef __SUNPRO_C
#pragma align 4 (display_dialog_ui)
#endif
#ifdef __GNUC__
static const char display_dialog_ui[] __attribute__ ((__aligned__ (4))) =
#else
static const char display_dialog_ui[] =
#endif
{
  "<?xml version=\"1.0\" encoding=\"UTF-8\"?><interface><requires lib=\"gt"
  "k+\" version=\"3.20\"/><requires lib=\"libxfce4ui-2\" version=\"4.13\"/"
  "><object class=\"GtkAdjustment\" id=\"adjustment1\"><property name=\"lo"
  "wer\">0.10</property><property name=\"upper\">10</property><property na"
  "me=\"step-increment\">0.10</property><property name=\"page-increment\">"
  "1</property></object><object class=\"GtkImage\" id=\"image1\"><property"
  " name=\"visible\">True</property><property name=\"can-focus\">False</pr"
  "operty><property name=\"icon-name\">edit-delete-symbolic</property></ob"
  "ject><object class=\"GtkImage\" id=\"image2\"><property name=\"visible\""
  ">True</property><property name=\"can-focus\">False</property><property "
  "name=\"icon-name\">document-save-symbolic</property></object><object cl"
  "ass=\"GtkImage\" id=\"image3\"><property name=\"visible\">True</propert"
  "y><property name=\"can-focus\">False</property><property name=\"icon-na"
  "me\">window-close-symbolic</property></object><object class=\"GtkImage\""
  " id=\"image4\"><property name=\"visible\">True</property><property name"
  "=\"can-focus\">False</property><property name=\"icon-name\">object-sele"
  "ct-symbolic</property></object><object class=\"GtkImage\" id=\"image5\""
  "><property name=\"visible\">True</property><property name=\"can-focus\""
  ">False</property><property name=\"icon-name\">document-new-symbolic</pr"
  "operty></object><object class=\"GtkImage\" id=\"image6\"><property name"
  "=\"visible\">True</property><property name=\"can-focus\">False</propert"
  "y><property name=\"icon-name\">help-browser</property></object><object "
  "class=\"GtkImage\" id=\"image7\"><property name=\"visible\">True</prope"
  "rty><property name=\"can-focus\">False</property><property name=\"icon-"
  "name\">object-select-symbolic</property></object><object class=\"GtkLis"
  "tStore\" id=\"liststore1\"><columns><column type=\"gchararray\"/><colum"
  "n type=\"gdouble\"/></columns><data><row><col id=\"0\">1x</col><col id="
  "\"1\">1</col></row><row><col id=\"0\" translatable=\"yes\">1.25x</col><"
  "col id=\"1\">1.25</col></row><row><col id=\"0\" translatable=\"yes\">1."
  "5x</col><col id=\"1\">1.5</col></row><row><col id=\"0\" translatable=\""
  "yes\">1.75x</col><col id=\"1\">1.75</col></row><row><col id=\"0\" trans"
  "latable=\"yes\">2x</col><col id=\"1\">2</col></row><row><col id=\"0\" t"
  "ranslatable=\"yes\">Custom:</col><col id=\"1\">-1</col></row></data></o"
  "bject><object class=\"GtkListStore\" id=\"liststore2\"><columns><column"
  " type=\"gchararray\"/><column type=\"guint\"/></columns><data><row><col"
  " id=\"0\" translatable=\"yes\">Do nothing</col><col id=\"1\">0</col></r"
  "ow><row><col id=\"0\" translatable=\"yes\">Show dialog</col><col id=\"1"
  "\">1</col></row><row><col id=\"0\" translatable=\"yes\">Mirror</col><co"
  "l id=\"1\">2</col></row><row><col id=\"0\" translatable=\"yes\">Extend<"
  "/col><col id=\"1\">3</col></row></data></object><object class=\"GtkPopo"
  "ver\" id=\"primary-info\"><property name=\"can-focus\">False</property>"
  "<property name=\"position\">bottom</property><child><object class=\"Gtk"
  "Grid\"><property name=\"visible\">True</property><property name=\"can-f"
  "ocus\">False</property><property name=\"margin-left\">12</property><pro"
  "perty name=\"margin-right\">12</property><property name=\"margin-top\">"
  "12</property><property name=\"margin-bottom\">12</property><child><obje"
  "ct class=\"GtkImage\" id=\"panel-ok\"><property name=\"can-focus\">Fals"
  "e</property><property name=\"margin-left\">18</property><property name="
  "\"icon-name\">emblem-ok-symbolic</property><style><class name=\"success"
  "\"/></style></object><packing><property name=\"left-attach\">0</propert"
  "y><property name=\"top-attach\">1</property></packing></child><child><o"
  "bject class=\"GtkImage\" id=\"desktop-ok\"><property name=\"can-focus\""
  ">False</property><property name=\"margin-left\">18</property><property "
  "name=\"icon-name\">emblem-ok-symbolic</property></object><packing><prop"
  "erty name=\"left-attach\">0</property><property name=\"top-attach\">2</"
  "property></packing></child><child><object class=\"GtkImage\" id=\"notif"
  "ications-ok\"><property name=\"can-focus\">False</property><property na"
  "me=\"margin-left\">18</property><property name=\"icon-name\">emblem-ok-"
  "symbolic</property></object><packing><property name=\"left-attach\">0</"
  "property><property name=\"top-attach\">3</property></packing></child><c"
  "hild><object class=\"GtkLabel\"><property name=\"visible\">True</proper"
  "ty><property name=\"can-focus\">False</property><property name=\"margin"
  "-bottom\">12</property><property name=\"label\" translatable=\"yes\">Th"
  "e primary display is currently configured to show:</property><property "
  "name=\"xalign\">0</property></object><packing><property name=\"left-att"
  "ach\">0</property><property name=\"top-attach\">0</property><property n"
  "ame=\"width\">3</property></packing></child><child><object class=\"GtkL"
  "abel\" id=\"panel-label\"><property name=\"visible\">True</property><pr"
  "operty name=\"can-focus\">False</property><property name=\"hexpand\">Tr"
  "ue</property><property name=\"label\" translatable=\"yes\">Xfce Panel</"
  "property><property name=\"xalign\">0</property></object><packing><prope"
  "rty name=\"left-attach\">1</property><property name=\"top-attach\">1</p"
  "roperty></packing></child><child><object class=\"GtkLabel\" id=\"deskto"
  "p-label\"><property name=\"visible\">True</property><property name=\"ca"
  "n-focus\">False</property><property name=\"hexpand\">True</property><pr"
  "operty name=\"label\" translatable=\"yes\">Desktop icons</property><pro"
  "perty name=\"xalign\">0</property></object><packing><property name=\"le"
  "ft-attach\">1</property><property name=\"top-attach\">2</property></pac"
  "king></child><child><object class=\"GtkLabel\" id=\"notifications-label"
  "\"><property name=\"visible\">True</property><property name=\"can-focus"
  "\">False</property><property name=\"hexpand\">True</property><property "
  "name=\"label\" translatable=\"yes\">Notifications</property><property n"
  "ame=\"xalign\">0</property></object><packing><property name=\"left-atta"
  "ch\">1</property><property name=\"top-attach\">3</property></packing></"
  "child><child><object class=\"GtkButton\" id=\"panel-configure\"><proper"
  "ty name=\"label\" translatable=\"yes\">Configure...</property><property"
  " name=\"visible\">True</property><property name=\"can-focus\">True</pro"
  "perty><property name=\"receives-default\">True</property><style><class "
  "name=\"flat\"/></style></object><packing><property name=\"left-attach\""
  ">2</property><property name=\"top-attach\">1</property></packing></chil"
  "d><child><object class=\"GtkButton\" id=\"desktop-configure\"><property"
  " name=\"label\" translatable=\"yes\">Configure...</property><property n"
  "ame=\"visible\">True</property><property name=\"can-focus\">True</prope"
  "rty><property name=\"receives-default\">True</property><style><class na"
  "me=\"flat\"/></style></object><packing><property name=\"left-attach\">2"
  "</property><property name=\"top-attach\">2</property></packing></child>"
  "<child><object class=\"GtkButton\" id=\"notifications-configure\"><prop"
  "erty name=\"label\" translatable=\"yes\">Configure...</property><proper"
  "ty name=\"visible\">True</property><property name=\"can-focus\">True</p"
  "roperty><property name=\"receives-default\">True</property><style><clas"
  "s name=\"flat\"/></style></object><packing><property name=\"left-attach"
  "\">2</property><property name=\"top-attach\">3</property></packing></ch"
  "ild></object></child></object><object class=\"XfceTitledDialog\" id=\"d"
  "isplay-dialog\"><property name=\"can-focus\">False</property><property "
  "name=\"title\" translatable=\"yes\">Display</property><property name=\""
  "window-position\">center-on-parent</property><property name=\"default-w"
  "idth\">400</property><property name=\"default-height\">400</property><p"
  "roperty name=\"icon-name\">org.xfce.settings.display</property><propert"
  "y name=\"type-hint\">dialog</property><child internal-child=\"vbox\"><o"
  "bject class=\"GtkBox\" id=\"dialog-vbox1\"><property name=\"visible\">T"
  "rue</property><property name=\"can-focus\">False</property><property na"
  "me=\"orientation\">vertical</property><property name=\"spacing\">2</pro"
  "perty><child internal-child=\"action_area\"><object class=\"GtkButtonBo"
  "x\" id=\"dialog-action_area1\"><property name=\"visible\">True</propert"
  "y><property name=\"can-focus\">False</property><property name=\"layout-"
  "style\">end</property><child><object class=\"GtkButton\" id=\"button-he"
  "lp\"><property name=\"label\" translatable=\"yes\">_Help</property><pro"
  "perty name=\"visible\">True</property><property name=\"can-focus\">True"
  "</property><property name=\"receives-default\">True</property><property"
  " name=\"image\">image6</property><property name=\"use-underline\">True<"
  "/property></object><packing><property name=\"expand\">False</property><"
  "property name=\"fill\">False</property><property name=\"position\">0</p"
  "roperty><property name=\"secondary\">True</property></packing></child><"
  "child><object class=\"GtkButton\" id=\"button-close\"><property name=\""
  "label\" translatable=\"yes\">_Close</property><property name=\"visible\""
  ">True</property><property name=\"can-focus\">True</property><property n"
  "ame=\"receives-default\">True</property><property name=\"image\">image3"
  "</property><property name=\"use-underline\">True</property></object><pa"
  "cking><property name=\"expand\">False</property><property name=\"fill\""
  ">False</property><property name=\"position\">1</property></packing></ch"
  "ild></object><packing><property name=\"expand\">False</property><proper"
  "ty name=\"fill\">True</property><property name=\"pack-type\">end</prope"
  "rty><property name=\"position\">1</property></packing></child><child><o"
  "bject class=\"GtkBox\" id=\"plug-child\"><property name=\"visible\">Tru"
  "e</property><property name=\"can-focus\">False</property><property name"
  "=\"border-width\">6</property><property name=\"orientation\">vertical</"
  "property><property name=\"spacing\">6</property><child><object class=\""
  "GtkNotebook\"><property name=\"visible\">True</property><property name="
  "\"can-focus\">True</property><property name=\"hexpand\">True</property>"
  "<property name=\"vexpand\">True</property><child><object class=\"GtkBox"
  "\"><property name=\"visible\">True</property><property name=\"can-focus"
  "\">False</property><property name=\"margin-left\">12</property><propert"
  "y name=\"margin-right\">12</property><property name=\"margin-top\">12</"
  "property><property name=\"margin-bottom\">12</property><property name=\""
  "spacing\">6</property><child><object class=\"GtkBox\" id=\"display-sett"
  "ings\"><property name=\"visible\">True</property><property name=\"can-f"
  "ocus\">False</property><property name=\"orientation\">vertical</propert"
  "y><property name=\"spacing\">9</property><child><object class=\"GtkFram"
  "e\"><property name=\"visible\">True</property><property name=\"can-focu"
  "s\">False</property><property name=\"label-xalign\">0</property><proper"
  "ty name=\"label-yalign\">0</property><property name=\"shadow-type\">in<"
  "/property><child><object class=\"GtkAlignment\" id=\"randr-dnd\"><prope"
  "rty name=\"width-request\">350</property><property name=\"visible\">Tru"
  "e</property><property name=\"can-focus\">False</property><child><placeh"
  "older/></child></object></child><child type=\"label_item\"><placeholder"
  "/></child></object><packing><property name=\"expand\">True</property><p"
  "roperty name=\"fill\">True</property><property name=\"position\">0</pro"
  "perty></packing></child><child><object class=\"GtkCheckButton\" id=\"mi"
  "rror-displays\"><property name=\"label\" translatable=\"yes\">_Mirror d"
  "isplays</property><property name=\"visible\">True</property><property n"
  "ame=\"can-focus\">True</property><property name=\"receives-default\">Fa"
  "lse</property><property name=\"use-underline\">True</property><property"
  " name=\"draw-indicator\">True</property></object><packing><property nam"
  "e=\"expand\">False</property><property name=\"fill\">True</property><pr"
  "operty name=\"position\">1</property></packing></child></object><packin"
  "g><property name=\"expand\">True</property><property name=\"fill\">True"
  "</property><property name=\"position\">0</property></packing></child><c"
  "hild><object class=\"GtkGrid\" id=\"table1\"><property name=\"visible\""
  ">True</property><property name=\"can-focus\">False</property><property "
  "name=\"row-spacing\">3</property><property name=\"column-spacing\">3</p"
  "roperty><child><object class=\"GtkBox\"><property name=\"visible\">True"
  "</property><property name=\"can-focus\">False</property><property name="
  "\"margin-bottom\">3</property><property name=\"spacing\">12</property><"
  "child><object class=\"GtkComboBox\" id=\"randr-outputs\"><property name"
  "=\"visible\">True</property><property name=\"can-focus\">False</propert"
  "y><property name=\"hexpand\">True</property></object><packing><property"
  " name=\"expand\">False</property><property name=\"fill\">True</property"
  "><property name=\"position\">0</property></packing></child><child><obje"
  "ct class=\"GtkSwitch\" id=\"output-on\"><property name=\"visible\">True"
  "</property><property name=\"can-focus\">True</property><property name=\""
  "halign\">end</property><property name=\"valign\">center</property></obj"
  "ect><packing><property name=\"expand\">False</property><property name=\""
  "fill\">True</property><property name=\"position\">1</property></packing"
  "></child></object><packing><property name=\"left-attach\">0</property><"
  "property name=\"top-attach\">0</property><property name=\"width\">4</pr"
  "operty></packing></child><child><object class=\"GtkMenuButton\" id=\"pr"
  "imary-info-button\"><property name=\"visible\">True</property><property"
  " name=\"can-focus\">True</property><property name=\"receives-default\">"
  "True</property><property name=\"relief\">none</property><property name="
  "\"popover\">primary-info</property><child><placeholder/></child></objec"
  "t><packing><property name=\"left-attach\">3</property><property name=\""
  "top-attach\">1</property></packing></child><child><object class=\"GtkSw"
  "itch\" id=\"primary\"><property name=\"visible\">True</property><proper"
  "ty name=\"can-focus\">True</property><property name=\"halign\">end</pro"
  "perty><property name=\"valign\">center</property><property name=\"margi"
  "n-left\">9</property><property name=\"margin-bottom\">3</property></obj"
  "ect><packing><property name=\"left-attach\">2</property><property name="
  "\"top-attach\">1</property></packing></child><child><object class=\"Gtk"
  "Label\" id=\"label-primary\"><property name=\"visible\">True</property>"
  "<property name=\"can-focus\">False</property><property name=\"halign\">"
  "start</property><property name=\"margin-bottom\">3</property><property "
  "name=\"label\" translatable=\"yes\">Primary Display:</property><propert"
  "y name=\"use-underline\">True</property></object><packing><property nam"
  "e=\"left-attach\">1</property><property name=\"top-attach\">1</property"
  "></packing></child><child><object class=\"GtkComboBox\" id=\"randr-reso"
  "lution\"><property name=\"visible\">True</property><property name=\"can"
  "-focus\">False</property><property name=\"margin-left\">9</property><pr"
  "operty name=\"margin-bottom\">3</property></object><packing><property n"
  "ame=\"left-attach\">2</property><property name=\"top-attach\">2</proper"
  "ty></packing></child><child><object class=\"GtkLabel\" id=\"label-resol"
  "ution\"><property name=\"visible\">True</property><property name=\"can-"
  "focus\">False</property><property name=\"halign\">start</property><prop"
  "erty name=\"margin-bottom\">3</property><property name=\"label\" transl"
  "atable=\"yes\">R_esolution:</property><property name=\"use-underline\">"
  "True</property></object><packing><property name=\"left-attach\">1</prop"
  "erty><property name=\"top-attach\">2</property></packing></child><child"
  "><object class=\"GtkComboBox\" id=\"randr-refresh-rate\"><property name"
  "=\"visible\">True</property><property name=\"can-focus\">False</propert"
  "y><property name=\"margin-left\">9</property><property name=\"margin-bo"
  "ttom\">3</property></object><packing><property name=\"left-attach\">2</"
  "property><property name=\"top-attach\">5</property></packing></child><c"
  "hild><object class=\"GtkLabel\" id=\"label-refresh-rate\"><property nam"
  "e=\"visible\">True</property><property name=\"can-focus\">False</proper"
  "ty><property name=\"halign\">start</property><property name=\"margin-bo"
  "ttom\">3</property><property name=\"label\" translatable=\"yes\">Refres"
  "h _rate:</property><property name=\"use-underline\">True</property></ob"
  "ject><packing><property name=\"left-attach\">1</property><property name"
  "=\"top-attach\">5</property></packing></child><child><object class=\"Gt"
  "kComboBox\" id=\"randr-rotation\"><property name=\"visible\">True</prop"
  "erty><property name=\"can-focus\">False</property><property name=\"marg"
  "in-left\">9</property><property name=\"margin-bottom\">3</property></ob"
  "ject><packing><property name=\"left-attach\">2</property><property name"
  "=\"top-attach\">6</property></packing></child><child><object class=\"Gt"
  "kLabel\" id=\"label-rotation\"><property name=\"visible\">True</propert"
  "y><property name=\"can-focus\">False</property><property name=\"halign\""
  ">start</property><property name=\"margin-bottom\">3</property><property"
  " name=\"label\" translatable=\"yes\">Ro_tation:</property><property nam"
  "e=\"use-underline\">True</property></object><packing><property name=\"l"
  "eft-attach\">1</property><property name=\"top-attach\">6</property></pa"
  "cking></child><child><object class=\"GtkComboBox\" id=\"randr-reflectio"
  "n\"><property name=\"can-focus\">False</property><property name=\"margi"
  "n-left\">9</property><property name=\"margin-bottom\">3</property></obj"
  "ect><packing><property name=\"left-attach\">2</property><property name="
  "\"top-attach\">7</property></packing></child><child><object class=\"Gtk"
  "Label\" id=\"label-reflection\"><property name=\"can-focus\">False</pro"
  "perty><property name=\"halign\">start</property><property name=\"margin"
  "-bottom\">3</property><property name=\"label\" translatable=\"yes\">Ref"
  "_lection:</property><property name=\"use-underline\">True</property></o"
  "bject><packing><property name=\"left-attach\">1</property><property nam"
  "e=\"top-attach\">7</property></packing></child><child><object class=\"G"
  "tkImage\" id=\"primary-indicator\"><property name=\"visible\">True</pro"
  "perty><property name=\"can-focus\">False</property><property name=\"val"
  "ign\">center</property><property name=\"margin-left\">6</property><prop"
  "erty name=\"pixel-size\">16</property><property name=\"icon-name\">help"
  "-about-symbolic</property></object><packing><property name=\"left-attac"
  "h\">0</property><property name=\"top-attach\">1</property></packing></c"
  "hild><child><object class=\"GtkImage\" id=\"dummy-icon\"><property name"
  "=\"visible\">True</property><property name=\"can-focus\">False</propert"
  "y><property name=\"margin-left\">6</property><property name=\"pixel-siz"
  "e\">16</property></object><packing><property name=\"left-attach\">0</pr"
  "operty><property name=\"top-attach\">2</property></packing></child><chi"
  "ld><object class=\"GtkBox\" id=\"hbox1\"><property name=\"visible\">Tru"
  "e</property><property name=\"can-focus\">False</property><child><placeh"
  "older/></child><child><object class=\"GtkButton\" id=\"apply\"><propert"
  "y name=\"label\" translatable=\"yes\">A_pply</property><property name=\""
  "visible\">True</property><property name=\"can-focus\">True</property><p"
  "roperty name=\"receives-default\">True</property><property name=\"margi"
  "n-top\">6</property><property name=\"image\">image4</property><property"
  " name=\"use-underline\">True</property></object><packing><property name"
  "=\"expand\">False</property><property name=\"fill\">True</property><pro"
  "perty name=\"pack-type\">end</property><property name=\"position\">1</p"
  "roperty></packing></child></object><packing><property name=\"left-attac"
  "h\">0</property><property name=\"top-attach\">8</property><property nam"
  "e=\"width\">3</property></packing></child><child><object class=\"GtkLab"
  "el\" id=\"label-scale\"><property name=\"visible\">True</property><prop"
  "erty name=\"can-focus\">False</property><property name=\"halign\">start"
  "</property><property name=\"label\" translatable=\"yes\">_Scale:</prope"
  "rty><property name=\"use-underline\">True</property></object><packing><"
  "property name=\"left-attach\">1</property><property name=\"top-attach\""
  ">3</property></packing></child><child><object class=\"GtkRevealer\" id="
  "\"revealer-scale\"><property name=\"visible\">True</property><property "
  "name=\"can-focus\">False</property><property name=\"reveal-child\">True"
  "</property><child><object class=\"GtkGrid\"><property name=\"visible\">"
  "True</property><property name=\"can-focus\">False</property><property n"
  "ame=\"margin-left\">9</property><property name=\"margin-top\">3</proper"
  "ty><property name=\"margin-bottom\">3</property><property name=\"row-sp"
  "acing\">3</property><child><object class=\"GtkLabel\" id=\"label-scale-"
  "x\"><property name=\"visible\">True</property><property name=\"can-focu"
  "s\">False</property><property name=\"halign\">end</property><property n"
  "ame=\"label\" translatable=\"yes\">X:</property><property name=\"xalign"
  "\">1</property></object><packing><property name=\"left-attach\">0</prop"
  "erty><property name=\"top-attach\">0</property></packing></child><child"
  "><object class=\"GtkLabel\" id=\"label-scale-y\"><property name=\"visib"
  "le\">True</property><property name=\"can-focus\">False</property><prope"
  "rty name=\"halign\">end</property><property name=\"label\" translatable"
  "=\"yes\">Y:</property><property name=\"xalign\">1</property></object><p"
  "acking><property name=\"left-attach\">0</property><property name=\"top-"
  "attach\">1</property></packing></child><child><object class=\"GtkSpinBu"
  "tton\" id=\"spin-scale-x\"><property name=\"visible\">True</property><p"
  "roperty name=\"can-focus\">True</property><property name=\"halign\">end"
  "</property><property name=\"hexpand\">True</property><property name=\"a"
  "djustment\">adjustment1</property><property name=\"digits\">1</property"
  "></object><packing><property name=\"left-attach\">1</property><property"
  " name=\"top-attach\">0</property></packing></child><child><object class"
  "=\"GtkSpinButton\" id=\"spin-scale-y\"><property name=\"visible\">True<"
  "/property><property name=\"can-focus\">True</property><property name=\""
  "halign\">end</property><property name=\"hexpand\">True</property><prope"
  "rty name=\"adjustment\">adjustment1</property><property name=\"digits\""
  ">1</property></object><packing><property name=\"left-attach\">1</proper"
  "ty><property name=\"top-attach\">1</property></packing></child><child><"
  "placeholder/></child><child><placeholder/></child><child><placeholder/>"
  "</child><child><placeholder/></child><child><placeholder/></child></obj"
  "ect></child></object><packing><property name=\"left-attach\">2</propert"
  "y><property name=\"top-attach\">4</property></packing></child><child><o"
  "bject class=\"GtkComboBox\" id=\"randr-scale\"><property name=\"visible"
  "\">True</property><property name=\"can-focus\">False</property><propert"
  "y name=\"margin-left\">9</property><property name=\"model\">liststore1<"
  "/property><child><object class=\"GtkCellRendererText\" id=\"cellrendere"
  "rtext1\"/><attributes><attribute name=\"text\">0</attribute></attribute"
  "s></child></object><packing><property name=\"left-attach\">2</property>"
  "<property name=\"top-attach\">3</property></packing></child><child><pla"
  "ceholder/></child><child><placeholder/></child><child><placeholder/></c"
  "hild><child><placeholder/></child><child><placeholder/></child><child><"
  "placeholder/></child><child><placeholder/></child><child><placeholder/>"
  "</child><child><placeholder/></child><child><placeholder/></child><chil"
  "d><placeholder/></child><child><placeholder/></child><child><placeholde"
  "r/></child></object><packing><property name=\"expand\">False</property>"
  "<property name=\"fill\">True</property><property name=\"pack-type\">end"
  "</property><property name=\"position\">1</property></packing></child></"
  "object></child><child type=\"tab\"><object class=\"GtkLabel\"><property"
  " name=\"visible\">True</property><property name=\"can-focus\">False</pr"
  "operty><property name=\"label\" translatable=\"yes\">_General</property"
  "><property name=\"use-underline\">True</property></object><packing><pro"
  "perty name=\"tab-fill\">False</property></packing></child><child><objec"
  "t class=\"GtkGrid\"><property name=\"visible\">True</property><property"
  " name=\"can-focus\">False</property><property name=\"border-width\">12<"
  "/property><property name=\"row-spacing\">6</property><property name=\"c"
  "olumn-spacing\">12</property><child><object class=\"GtkLabel\" id=\"lab"
  "el-profile\"><property name=\"visible\">True</property><property name=\""
  "can-focus\">False</property><property name=\"halign\">start</property><"
  "property name=\"label\" translatable=\"yes\">&lt;b&gt;Profiles&lt;/b&gt"
  ";</property><property name=\"use-markup\">True</property><property name"
  "=\"use-underline\">True</property></object><packing><property name=\"le"
  "ft-attach\">0</property><property name=\"top-attach\">0</property><prop"
  "erty name=\"width\">2</property></packing></child><child><object class="
  "\"GtkLabel\" id=\"label-profile1\"><property name=\"visible\">True</pro"
  "perty><property name=\"can-focus\">False</property><property name=\"hal"
  "ign\">start</property><property name=\"margin-top\">12</property><prope"
  "rty name=\"label\" translatable=\"yes\">&lt;b&gt;Connecting Displays&lt"
  ";/b&gt;</property><property name=\"use-markup\">True</property><propert"
  "y name=\"use-underline\">True</property></object><packing><property nam"
  "e=\"left-attach\">0</property><property name=\"top-attach\">2</property"
  "><property name=\"width\">2</property></packing></child><child><object "
  "class=\"GtkBox\"><property name=\"visible\">True</property><property na"
  "me=\"can-focus\">False</property><property name=\"margin-left\">12</pro"
  "perty><property name=\"hexpand\">True</property><property name=\"orient"
  "ation\">vertical</property><child><object class=\"GtkScrolledWindow\"><"
  "property name=\"visible\">True</property><property name=\"can-focus\">T"
  "rue</property><property name=\"shadow-type\">in</property><child><objec"
  "t class=\"GtkTreeView\" id=\"randr-profile\"><property name=\"visible\""
  ">True</property><property name=\"can-focus\">True</property><property n"
  "ame=\"hexpand\">True</property><property name=\"vexpand\">True</propert"
  "y><property name=\"border-width\">1</property><child internal-child=\"s"
  "election\"><object class=\"GtkTreeSelection\"/></child></object></child"
  "></object><packing><property name=\"expand\">False</property><property "
  "name=\"fill\">True</property><property name=\"position\">0</property></"
  "packing></child><child><object class=\"GtkBox\"><property name=\"visibl"
  "e\">True</property><property name=\"can-focus\">False</property><child>"
  "<object class=\"GtkButton\" id=\"button-profile-delete\"><property name"
  "=\"visible\">True</property><property name=\"can-focus\">True</property"
  "><property name=\"receives-default\">True</property><property name=\"to"
  "oltip-text\" translatable=\"yes\">Delete the currently selected display"
  " profile.</property><property name=\"image\">image1</property><property"
  " name=\"always-show-image\">True</property></object><packing><property "
  "name=\"expand\">False</property><property name=\"fill\">True</property>"
  "<property name=\"pack-type\">end</property><property name=\"position\">"
  "-1</property></packing></child><child><object class=\"GtkButton\" id=\""
  "button-profile-apply\"><property name=\"label\" translatable=\"yes\">Ap"
  "ply</property><property name=\"visible\">True</property><property name="
  "\"can-focus\">True</property><property name=\"receives-default\">True</"
  "property><property name=\"tooltip-text\" translatable=\"yes\">Apply the"
  " currently selected display profile.</property><property name=\"image\""
  ">image7</property><property name=\"always-show-image\">True</property><"
  "/object><packing><property name=\"expand\">False</property><property na"
  "me=\"fill\">True</property><property name=\"pack-type\">end</property><"
  "property name=\"position\">0</property></packing></child><child><object"
  " class=\"GtkButton\" id=\"button-profile-create\"><property name=\"visi"
  "ble\">True</property><property name=\"can-focus\">True</property><prope"
  "rty name=\"receives-default\">True</property><property name=\"tooltip-t"
  "ext\" translatable=\"yes\">Create a new display profile.</property><pro"
  "perty name=\"image\">image5</property><property name=\"always-show-imag"
  "e\">True</property></object><packing><property name=\"expand\">False</p"
  "roperty><property name=\"fill\">True</property><property name=\"pack-ty"
  "pe\">end</property><property name=\"position\">1</property></packing></"
  "child><child><object class=\"GtkButton\" id=\"button-profile-save\"><pr"
  "operty name=\"visible\">True</property><property name=\"can-focus\">Tru"
  "e</property><property name=\"receives-default\">True</property><propert"
  "y name=\"tooltip-text\" translatable=\"yes\">Update an existing profile"
  ".</property><property name=\"image\">image2</property><property name=\""
  "always-show-image\">True</property></object><packing><property name=\"e"
  "xpand\">False</property><property name=\"fill\">True</property><propert"
  "y name=\"pack-type\">end</property><property name=\"position\">2</prope"
  "rty></packing></child><style><class name=\"inline-toolbar\"/></style></"
  "object><packing><property name=\"expand\">False</property><property nam"
  "e=\"fill\">True</property><property name=\"position\">1</property></pac"
  "king></child></object><packing><property name=\"left-attach\">0</proper"
  "ty><property name=\"top-attach\">1</property><property name=\"width\">2"
  "</property></packing></child><child><object class=\"GtkLabel\" id=\"aut"
  "o-enable-profiles-label\"><property name=\"visible\">True</property><pr"
  "operty name=\"can-focus\">False</property><property name=\"margin-left\""
  ">12</property><property name=\"label\" translatable=\"yes\">Automatical"
  "ly enable profiles when new display is connected</property><property na"
  "me=\"xalign\">0</property></object><packing><property name=\"left-attac"
  "h\">0</property><property name=\"top-attach\">4</property></packing></c"
  "hild><child><object class=\"GtkSwitch\" id=\"auto-enable-profiles\"><pr"
  "operty name=\"visible\">True</property><property name=\"can-focus\">Tru"
  "e</property><property name=\"halign\">end</property><property name=\"va"
  "lign\">center</property></object><packing><property name=\"left-attach\""
  ">1</property><property name=\"top-attach\">4</property></packing></chil"
  "d><child><object class=\"GtkLabel\"><property name=\"visible\">True</pr"
  "operty><property name=\"can-focus\">False</property><property name=\"ma"
  "rgin-left\">12</property><property name=\"label\" translatable=\"yes\">"
  "When new displays are connected:</property><property name=\"xalign\">0<"
  "/property></object><packing><property name=\"left-attach\">0</property>"
  "<property name=\"top-attach\">3</property></packing></child><child><obj"
  "ect class=\"GtkLabel\"><property name=\"visible\">True</property><prope"
  "rty name=\"can-focus\">False</property><property name=\"margin-left\">1"
  "2</property><property name=\"label\" translatable=\"yes\">Show popup wi"
  "ndows to identify displays</property><property name=\"xalign\">0</prope"
  "rty></object><packing><property name=\"left-attach\">0</property><prope"
  "rty name=\"top-attach\">6</property></packing></child><child><object cl"
  "ass=\"GtkSwitch\" id=\"identify-displays\"><property name=\"visible\">T"
  "rue</property><property name=\"can-focus\">True</property><property nam"
  "e=\"halign\">end</property><property name=\"valign\">center</property><"
  "/object><packing><property name=\"left-attach\">1</property><property n"
  "ame=\"top-attach\">6</property></packing></child><child><object class=\""
  "GtkLabel\" id=\"label-profile2\"><property name=\"visible\">True</prope"
  "rty><property name=\"can-focus\">False</property><property name=\"halig"
  "n\">start</property><property name=\"margin-top\">12</property><propert"
  "y name=\"label\" translatable=\"yes\">&lt;b&gt;Identifying Displays&lt;"
  "/b&gt;</property><property name=\"use-markup\">True</property><property"
  " name=\"use-underline\">True</property></object><packing><property name"
  "=\"left-attach\">0</property><property name=\"top-attach\">5</property>"
  "<property name=\"width\">2</property></packing></child><child><object c"
  "lass=\"GtkComboBox\" id=\"autoconnect-mode\"><property name=\"visible\""
  ">True</property><property name=\"can-focus\">False</property><property "
  "name=\"valign\">center</property><property name=\"model\">liststore2</p"
  "roperty><property name=\"id-column\">1</property><child><object class=\""
  "GtkCellRendererText\" id=\"cellrenderertext2\"/><attributes><attribute "
  "name=\"text\">0</attribute></attributes></child></object><packing><prop"
  "erty name=\"left-attach\">1</property><property name=\"top-attach\">3</"
  "property></packing></child><child><placeholder/></child><child><placeho"
  "lder/></child><child><placeholder/></child><child><placeholder/></child"
  "><child><placeholder/></child><child><placeholder/></child><child><plac"
  "eholder/></child></object><packing><property name=\"position\">1</prope"
  "rty></packing></child><child type=\"tab\"><object class=\"GtkLabel\"><p"
  "roperty name=\"visible\">True</property><property name=\"can-focus\">Fa"
  "lse</property><property name=\"label\" translatable=\"yes\">_Advanced</"
  "property><property name=\"use-underline\">True</property></object><pack"
  "ing><property name=\"position\">1</property><property name=\"tab-fill\""
  ">False</property></packing></child><child><placeholder/></child><child "
  "type=\"tab\"><placeholder/></child></object><packing><property name=\"e"
  "xpand\">False</property><property name=\"fill\">True</property><propert"
  "y name=\"position\">1</property></packing></child></object><packing><pr"
  "operty name=\"expand\">True</property><property name=\"fill\">True</pro"
  "perty><property name=\"position\">2</property></packing></child></objec"
  "t></child><action-widgets><action-widget response=\"-11\">button-help</"
  "action-widget><action-widget response=\"-7\">button-close</action-widge"
  "t></action-widgets></object><object class=\"GtkPopover\" id=\"popover-c"
  "reate-profile\"><property name=\"can-focus\">False</property><property "
  "name=\"relative-to\">button-profile-create</property><child><object cla"
  "ss=\"GtkBox\"><property name=\"visible\">True</property><property name="
  "\"can-focus\">False</property><property name=\"orientation\">vertical</"
  "property><child><object class=\"GtkGrid\"><property name=\"visible\">Tr"
  "ue</property><property name=\"can-focus\">False</property><property nam"
  "e=\"margin-left\">12</property><property name=\"margin-right\">12</prop"
  "erty><property name=\"margin-top\">12</property><property name=\"margin"
  "-bottom\">24</property><property name=\"row-spacing\">6</property><prop"
  "erty name=\"column-spacing\">6</property><child><object class=\"GtkLabe"
  "l\"><property name=\"visible\">True</property><property name=\"can-focu"
  "s\">False</property><property name=\"label\" translatable=\"yes\">&lt;b"
  "&gt;Profile Name&lt;/b&gt;</property><property name=\"use-markup\">True"
  "</property><property name=\"xalign\">0</property></object><packing><pro"
  "perty name=\"left-attach\">0</property><property name=\"top-attach\">0<"
  "/property></packing></child><child><object class=\"GtkEntry\" id=\"entr"
  "y-profile-create\"><property name=\"visible\">True</property><property "
  "name=\"can-focus\">True</property><property name=\"hexpand\">True</prop"
  "erty><property name=\"activates-default\">True</property></object><pack"
  "ing><property name=\"left-attach\">0</property><property name=\"top-att"
  "ach\">1</property></packing></child><child><object class=\"GtkButton\" "
  "id=\"button-profile-create-cb\"><property name=\"label\" translatable=\""
  "yes\">Create</property><property name=\"visible\">True</property><prope"
  "rty name=\"can-focus\">True</property><property name=\"can-default\">Tr"
  "ue</property><property name=\"has-default\">True</property><property na"
  "me=\"receives-default\">True</property><style><class name=\"suggested-a"
  "ction\"/></style></object><packing><property name=\"left-attach\">1</pr"
  "operty><property name=\"top-attach\">1</property></packing></child><chi"
  "ld><object class=\"GtkBox\" id=\"profile-exists\"><property name=\"visi"
  "ble\">True</property><property name=\"can-focus\">False</property><prop"
  "erty name=\"spacing\">6</property><child><object class=\"GtkImage\"><pr"
  "operty name=\"visible\">True</property><property name=\"can-focus\">Fal"
  "se</property><property name=\"icon-name\">dialog-error-symbolic</proper"
  "ty></object><packing><property name=\"expand\">True</property><property"
  " name=\"fill\">True</property><property name=\"position\">0</property><"
  "/packing></child><child><object class=\"GtkLabel\"><property name=\"can"
  "-focus\">False</property><property name=\"label\" translatable=\"yes\">"
  "A profile of this name already exists.</property></object><packing><pro"
  "perty name=\"expand\">True</property><property name=\"fill\">True</prop"
  "erty><property name=\"position\">1</property></packing></child></object"
  "><packing><property name=\"left-attach\">0</property><property name=\"t"
  "op-attach\">2</property><property name=\"width\">2</property></packing>"
  "</child><child><placeholder/></child><child><placeholder/></child><chil"
  "d><placeholder/></child><child><placeholder/></child></object><packing>"
  "<property name=\"expand\">False</property><property name=\"fill\">True<"
  "/property><property name=\"position\">0</property></packing></child></o"
  "bject></child></object></interface>"
};

static const unsigned display_dialog_ui_length = 34950u;

